function [edges_3d,G1S,G2S,G3S] = HybridWaveletCanny3Dedge(IMSS,sigma,nlevels)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [edges_3d,G1S,G2S,G3S] = HybridWaveletCanny3Dedge(IMSS,sigma,nlevels)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE: This is a 3D edge detection algorithm using
% wavelets and Canny.
% Input  IMSS is a 3D array containing the data:
%             intensity magnitudes at each voxel.
%       sigma is the standard deviation used
%             for Gaussian smoothing of images
%       nlevels is the number of levels in the wavelet transform
%             (default nlevels = 3)
% Output G1S,G2S,G3S are the estimated horizontal, vertical,
%             and time derivatives of the intensity at each voxel.
% Output edges_3d contains the estimated squared-magnitude of the
%             gradient at each voxel, normalized to have max 1.
% David A. Schug, Glenn R. Easley, Dianne P. O'Leary Fall 2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 3
   nlevels = 3;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the Wavelet 2D edge response over x and y
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[~,G1S,G2S] = Wavelet2Dedge(IMSS, nlevels);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the Canny 3D edge response over time
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[~, ~, ~, G3S] = Canny3Dedge(IMSS,sigma);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the squared-magnitude of the gradient at each
% voxel and return it in edges_3d.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

edges_3d = G1S.^2 + G2S.^2 + G3S.^2;

edges_3d = edges_3d / max(edges_3d(:));

