function Z = conv3(A,mask);

% function Z = myconv3(A,mask);
%
% This function matches the output of convn(A,mask,'same')
% when mask is k1 x k2 x k3 and k3 is odd.
%
% It uses Matlab's conv2 in the first 2 dimensions
% but adds the results manually to get the effect of the
% 3rd dimension.
%
% Therefore, it is designed to be efficient when the
% third dimension of mask is much less than that of A.
%
% Note that mask is reflected around 3rd dimension in
% both myconv3 and convn.
%
% Dianne P O'Leary 12/2010

[n1,n2,n3] = size(A);

[k1,k2,k3] = size(mask);

if rem(k3,2)==0
  error('The 3rd dimension of the mask must be odd.')
end

center = (k3-1)/2 + 1;

Z = zeros(n1,n2,n3);

for k=1:k3,
      kc = k - center;
      for j= max(1,1-kc) : min(n3,n3-kc)
          T = conv2(A(:,:,j+kc),mask(:,:,k3+1-k),'same');
          Z(:,:,j) = Z(:,:,j) + T;
      end
   end
end

