function Sh3D = shearing3D(winSize,level,fignum)
% modified wedge generation to include odd size supports
% this makes it easy for analysis since there is an exact center
% winSize - size of filter support or window function
% level - 2^level determines number of directions
% fignum - figure number for plotting (<= 0 suppresses plots)

% suppress plots?
if nargin < 3
    fignum = 0;
end

% generate 2-D shearing filter kernels for level
Sh2D = shearing_filters_Myer_odd(winSize,level);

n2d = 2^(level-1);

Sh3DZ = zeros(winSize,winSize,winSize,n2d);
Sh3DX = Sh3DZ;
for j = 1 : n2d
    for i=1:winSize
        Sh3DZ(:,:,i,j) = squeeze(Sh2D(:,:,j));
    end
    Sh3DX(:,:,:,j) = permute(squeeze(Sh3DZ(:,:,:,j)),[1 3 2]);
end

n2d2 = n2d^2;
% Initialize storage for shearing operator at given level
Sh3D = zeros(winSize,winSize,winSize,3*n2d2);
for j = 1 : n2d
    for k = 1 : n2d
        
        % Operator for Y direction
        Sh3D1 = squeeze(Sh3DZ(:,:,:,j)) .* squeeze(Sh3DX(:,:,:,k));
        % Store Y direction
        Sh3D(:,:,:,n2d*(j-1)+k)        = Sh3D1;
        % Operator for T direction
        Sh3D(:,:,:,n2d*(j-1)+k+n2d2)   = permute(Sh3D1,[2 3 1]);
        % Operator for X direction
        Sh3D(:,:,:,n2d*(j-1)+k+2*n2d2) = permute(Sh3D1,[3 1 2]);
    end
end
%% Normalize
S_sum = sum(Sh3D,4);
for p =1:size(Sh3D,4)
    Sh3D(:,:,:,p) = Sh3D(:,:,:,p)./S_sum;
end

%% Plot the independent reproducing structure for the 3D operator
if fignum > 0 
    for j = 1 : n2d
        PlotKernel3D(fignum, squeeze(Sh3DZ(:,:,:,j)), sprintf('Sh3DZ%d',j));
        fignum = fignum + 1;
        pause
        PlotKernel3D(fignum, squeeze(Sh3DX(:,:,:,j)), sprintf('Sh3DX%d',j));
        fignum = fignum + 1;
        pause
    end
    %  Plot the 3D shearing operators for 3 directions
    for i = 1 : 3
        % Partition for 1st dimension of plane
        for j = 1 : n2d
        % Partition for 2nd dimension of plane
            for k = 1 : n2d
                PlotKernel3D(fignum, squeeze(Sh3D(:,:,:,n2d2*(i-1)+n2d*(j-1)+k)), sprintf('Sh3D:%d,%d,%d',i,j,k));
                fignum = fignum + 1;
                pause
            end
        end
    end
end
