function y=symext_conv2D(x,h)

% FUNCTION y = symext_conv2D
% INPUT:  x,  image of size L1xL2
%         h, 2D filter coefficients
% OUTPUT: y  image symetrically extended convolved and extracted  
%
% Written by Glenn R. Easley on Sept. 12, 2007
% Mod by DPO 12/2012

[L1,L2] = size(x);
[Lh1,Lh2]=size(h);

beg_halfL = floor(Lh1/2) + 1;
beg_halfU = floor(Lh2/2) + 1;

% Pad x on all sides, using reflexive boundary conditions.

x_sym_ext = [x(:,(beg_halfU:-1:1)) x  x(:,(L2:-1:L2-beg_halfU+1))];
x_sym_ext = [x_sym_ext((beg_halfL:-1:1),:); x_sym_ext ;  ...
             x_sym_ext((L1:-1:L1-beg_halfL+1),:)];

% Perform the convolution.

y_ext=conv2(x_sym_ext,h,'same');

% Unpad the result.

y=y_ext(beg_halfL+1:beg_halfL+L1,beg_halfU+1:beg_halfU+L2);

